# DWhirlpool
## Presents
### Ptop
#### Top, But Written in Python
[![GitHub version](https://badge.fury.io/gh/DWhirlpool%2Fptop.svg)](https://badge.fury.io/gh/DWhirlpool%2Fptop)
[![codecov](https://codecov.io/gh/DWhirlpool/ptop/branch/main/graph/badge.svg?token=UKFXBEJBSY)](https://codecov.io/gh/DWhirlpool/ptop)
[![Documentation Status](https://readthedocs.org/projects/ptop/badge/?version=latest)](https://ptop.readthedocs.io/en/latest/?badge=latest)
[![Build status](https://ci.appveyor.com/api/projects/status/rk44r0r9s8d3l28o?svg=true)](https://ci.appveyor.com/project/DWhirlpool/ptop)
[![CircleCI](https://circleci.com/gh/DWhirlpool/ptop/tree/main.svg?style=svg)](https://circleci.com/gh/DWhirlpool/ptop/tree/main)
![W3C Validation](https://img.shields.io/w3c-validation/html?style=flat-square&targetUrl=https%3A%2F%2Fdwhirlpool.github.io%2Fptop)
<img src="https://forthebadge.com/images/badges/built-with-love.svg"></img>

Brought to you using  ![Visual Studio Code](https://img.shields.io/badge/Visual%20Studio%20Code-0078d7.svg?style=for-the-badge&logo=visual-studio-code&logoColor=white)
## Table of contents
* [General info](#general-info)
* [Usage](#Usage)
## General info
Based on the Unix command 
```
top
```
But written in python
## Usage
1. Extract Files
2. Move All the Files into the C:\Users\username, or if you have administrative access, C:\Windows\System32.
3. If You did C:\Users\username, then open up Windows Command Processor(cmd) without administrative access
```
C:\Users\username>ptop
```
3. If you did C:\Windows\System32, then open up Windows Command Processor(cmd) as Administrator
```
C:\Windows\System32>ptop
```
4. Have Fun! :D